pub trait JmapMailExt {
// Required method
fn with_mail_session(&self, session: Session) -> SessionClient;
}Expand description
Extension trait adding RFC 8621 (JMAP for Mail) methods to jmap_base_client::JmapClient.
Import this trait to use: use jmap_mail_client::JmapMailExt;
All JMAP Mail method calls are made through the SessionClient returned
by with_mail_session.
Required Methods
Sourcefn with_mail_session(&self, session: Session) -> SessionClient
fn with_mail_session(&self, session: Session) -> SessionClient
Create a SessionClient bound to this client and session.
All JMAP Mail method calls are made through the returned SessionClient.